# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: pubsub.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0cpubsub.proto\"\x1d\n\nSubRequest\x12\x0f\n\x07payload\x18\x01 \x01(\t\"\x1e\n\x0bSubResponse\x12\x0f\n\x07payload\x18\x01 \x01(\t\"\x1d\n\nPubRequest\x12\x0f\n\x07payload\x18\x01 \x01(\t\"\x1e\n\x0bPubResponse\x12\x0f\n\x07payload\x18\x01 \x01(\t2\x88\x01\n\x10PublisherService\x12\"\n\x03\x41\x64\x64\x12\x0b.SubRequest\x1a\x0c.SubResponse\"\x00\x12%\n\x06Remove\x12\x0b.SubRequest\x1a\x0c.SubResponse\"\x00\x12)\n\x06Notify\x12\x0b.SubRequest\x1a\x0c.SubResponse\"\x00(\x01\x30\x01\x32>\n\x11SubscriberService\x12)\n\x06Update\x12\x0b.PubRequest\x1a\x0c.PubResponse\"\x00(\x01\x30\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'pubsub_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_SUBREQUEST']._serialized_start=16
  _globals['_SUBREQUEST']._serialized_end=45
  _globals['_SUBRESPONSE']._serialized_start=47
  _globals['_SUBRESPONSE']._serialized_end=77
  _globals['_PUBREQUEST']._serialized_start=79
  _globals['_PUBREQUEST']._serialized_end=108
  _globals['_PUBRESPONSE']._serialized_start=110
  _globals['_PUBRESPONSE']._serialized_end=140
  _globals['_PUBLISHERSERVICE']._serialized_start=143
  _globals['_PUBLISHERSERVICE']._serialized_end=279
  _globals['_SUBSCRIBERSERVICE']._serialized_start=281
  _globals['_SUBSCRIBERSERVICE']._serialized_end=343
# @@protoc_insertion_point(module_scope)
