# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: connector.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0f\x63onnector.proto\x1a\x19google/protobuf/any.proto\"0\n\x11\x44ispatcherRequest\x12\x1b\n\x07payload\x18\x01 \x01(\x0b\x32\n.ListValue\"1\n\x12\x44ispatcherResponse\x12\x1b\n\x07payload\x18\x01 \x01(\x0b\x32\n.ListValue\"d\n\x06Struct\x12#\n\x06\x66ields\x18\x01 \x03(\x0b\x32\x13.Struct.FieldsEntry\x1a\x35\n\x0b\x46ieldsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x15\n\x05value\x18\x02 \x01(\x0b\x32\x06.Value:\x02\x38\x01\"\xba\x01\n\x05Value\x12 \n\nnull_value\x18\x01 \x01(\x0e\x32\n.NullValueH\x00\x12\x16\n\x0cnumber_value\x18\x02 \x01(\x01H\x00\x12\x16\n\x0cstring_value\x18\x03 \x01(\tH\x00\x12\x14\n\nbool_value\x18\x04 \x01(\x08H\x00\x12\x1f\n\x0cstruct_value\x18\x05 \x01(\x0b\x32\x07.StructH\x00\x12 \n\nlist_value\x18\x06 \x01(\x0b\x32\n.ListValueH\x00\x42\x06\n\x04kind\"#\n\tListValue\x12\x16\n\x06values\x18\x01 \x03(\x0b\x32\x06.Value*\x1b\n\tNullValue\x12\x0e\n\nNULL_VALUE\x10\x00\x32K\n\x10\x43onnectorService\x12\x37\n\nDispatcher\x12\x12.DispatcherRequest\x1a\x13.DispatcherResponse\"\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'connector_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _STRUCT_FIELDSENTRY._options = None
  _STRUCT_FIELDSENTRY._serialized_options = b'8\001'
  _globals['_NULLVALUE']._serialized_start=475
  _globals['_NULLVALUE']._serialized_end=502
  _globals['_DISPATCHERREQUEST']._serialized_start=46
  _globals['_DISPATCHERREQUEST']._serialized_end=94
  _globals['_DISPATCHERRESPONSE']._serialized_start=96
  _globals['_DISPATCHERRESPONSE']._serialized_end=145
  _globals['_STRUCT']._serialized_start=147
  _globals['_STRUCT']._serialized_end=247
  _globals['_STRUCT_FIELDSENTRY']._serialized_start=194
  _globals['_STRUCT_FIELDSENTRY']._serialized_end=247
  _globals['_VALUE']._serialized_start=250
  _globals['_VALUE']._serialized_end=436
  _globals['_LISTVALUE']._serialized_start=438
  _globals['_LISTVALUE']._serialized_end=473
  _globals['_CONNECTORSERVICE']._serialized_start=504
  _globals['_CONNECTORSERVICE']._serialized_end=579
# @@protoc_insertion_point(module_scope)
